task

package
v0.0.0-...-678040a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

const (
	// KeyRedisConnection is the oncall key prefix for redis connection errors
	KeyRedisConnection = "redis_connection_error"
	// RedisHealthCheckInterval is how often to ping redis
	RedisHealthCheckInterval = 30 * time.Second
	// RedisErrorPersistDuration is how long redis errors must persist before triggering urgent alert
	RedisErrorPersistDuration = 2 * time.Minute
)

Variables

This section is empty.

Functions

func AsyncUsagePollTask

func AsyncUsagePollTask(ctx context.Context)

func AutoTestBannedModelsTask

func AutoTestBannedModelsTask(ctx context.Context)

AutoTestBannedModelsTask 自动测试被禁用的模型

func CleanLogTask

func CleanLogTask(ctx context.Context)

CleanLogTask 清理日志任务

func DetectIPGroupsTask

func DetectIPGroupsTask(ctx context.Context)

DetectIPGroupsTask 检测 IP 使用多个 group 的情况

func RedisHealthCheckTask

func RedisHealthCheckTask(ctx context.Context)

RedisHealthCheckTask monitors Redis connection health

func UsageAlertTask

func UsageAlertTask(ctx context.Context)

UsageAlertTask 用量异常告警任务

Types

This section is empty.

Jump to