Documentation
¶
Index ¶
Constants ¶
const ( // KeyRedisConnection is the oncall key prefix for redis connection errors KeyRedisConnection = "redis_connection_error" // RedisHealthCheckInterval is how often to ping redis RedisHealthCheckInterval = 30 * time.Second // RedisErrorPersistDuration is how long redis errors must persist before triggering urgent alert RedisErrorPersistDuration = 2 * time.Minute )
Variables ¶
This section is empty.
Functions ¶
func AsyncUsagePollTask ¶
func AutoTestBannedModelsTask ¶
AutoTestBannedModelsTask 自动测试被禁用的模型
func DetectIPGroupsTask ¶
DetectIPGroupsTask 检测 IP 使用多个 group 的情况
func RedisHealthCheckTask ¶
RedisHealthCheckTask monitors Redis connection health
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.